embassy-stm32

Crates

git

Versions

stm32h7b0zb

Flavors

DFSDM2

Struct DFSDM2 

pub struct DFSDM2 { /* private fields */ }
DFSDM2 peripheral

Implementations

Source

impl DFSDM2

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.